@@ -488,8 +488,6 @@ signals:
 
     void signalEnableDirWatch(bool enable);
 
-    void coverChanged();
-
     void signalPlaylistItemsDropped(Playlist *p);
 
 private:
@@ -663,7 +661,6 @@ private:
     WebImageFetcher *m_fetcher;
 
     int m_currentColumn;
-    int m_processed;
     QAction *m_rmbEdit;
     int m_selectedCount;
 
@@ -718,7 +715,7 @@ private:
     static bool m_visibleChanged;
     static bool m_shuttingDown;
     static int m_leftColumn;
-    static QMap<int, PlaylistItem *> m_backMenuItems;
+    static QVector<PlaylistItem *> m_backMenuItems;
 
     bool m_blockDataChanged;
 };
