@@ -79,6 +79,8 @@ PlaylistSplitter::~PlaylistSplitter()
 
     delete m_editor;
 
+    delete m_lyricsWidget;
+
     // NowPlaying depends on the PlaylistCollection, so kill it now.
     delete m_nowPlaying;
     m_nowPlaying = 0;
@@ -246,6 +248,7 @@ void PlaylistSplitter::setupLayout()
 
     topLayout->addWidget(m_nowPlaying);
     topLayout->addWidget(m_searchWidget);
+    topLayout->insertStretch(-1); // Force search bar to top while playlistStack hides
     topLayout->addWidget(m_playlistStack, 1);
 
     // Now that GUI setup is complete, add some auto-update signals.
